@@ -1,4 +1,4 @@
-# mesonet_extractor.py
+# okmesopy.py
 #
 # Abhiram Pamula (apamula@okstate.edu)
 # Ben Rubinstein (brubinst@hawk.iit.edu)
@@ -21,9 +21,8 @@ from pyproj import CRS , Transformer
 from pandas.errors import EmptyDataError
 
 class MesonetExtractor:
-    """
-    """
-    
+
+
     def __init__(self, destination=None, verbose=False):
         '''
         init method for MesonetExtractor class
@@ -93,7 +92,7 @@ class MesonetExtractor:
                 attempt = 0
                 while attempt < self.TTL:
                     try:
-                        urllib.request.urlretrieve(meta_url,self.destination)
+                        urllib.request.urlretrieve(meta_url,'{}/geoinfo.csv'.format(self.destination))
                         self.metadata = pd.read_csv('{}/{}'.format(self.destination,meta_file))
                         break
                     except Exception as e:
@@ -110,6 +109,14 @@ class MesonetExtractor:
                                     ' details.')
 
 
+    def get_station_ids(self):
+        '''
+        Returns a list of all the valid station IDs (STIDs) from the metadata
+            file
+        '''
+        return ' '.join(self.metadata['stid'].values[1:])
+
+
     def download_station_data(self,site_id,start_date,end_date):
         '''
         Method to download data for a single station over a specified time
@@ -171,7 +178,7 @@ class MesonetExtractor:
         final_df = pd.concat(df_list)
         final_df = final_df.reset_index(drop=True)
         return self.rep_unknown(final_df.copy(deep = True))
-    
+
 
     def rep_unknown(self,df):
         '''
@@ -185,7 +192,7 @@ class MesonetExtractor:
             df = df.replace(str(i),np.nan)
             df = df.replace(i,np.nan)
         return df
-    
+
 
     def download_bounding_box(self,bbox,start_date,end_date,padding=1):
         '''
@@ -271,8 +278,8 @@ class MesonetExtractor:
                 return None
         df = self.download_bounding_box(bbox,start_date,end_date,padding)
         return df
-      
-        
+
+
     def download_shape_file(self,shape_path,start_date,end_date,padding=1,prj_path=''):
         '''
         Reads a shape file from the specified path and downloads all data for
@@ -308,7 +315,7 @@ class MesonetExtractor:
             sf.close()
         return df
 
-    
+
     def fill_nei_state_data(self,master_df):
         '''
         Fills missing data using data from the nearest station.
@@ -317,9 +324,9 @@ class MesonetExtractor:
             master_df is the dataframe with missing dates to correct
         ''' 
         # TODO: get this working and optimize it
-        missing_ddates = list(master_df[master_df.isna().any(axis=1)]['date'].unique())
-        cols = list(master_df.columns)
-        unwanted = ['STID', 'STNM', 'TIME', 'date', 'date_time']
+        #missing_ddates = list(master_df[master_df.isna().any(axis=1)]['date'].unique())
+        #cols = list(master_df.columns)
+        #unwanted = ['STID', 'STNM', 'TIME', 'date', 'date_time']
         #clim_pars =[i for i in cols if i not in unwanted]
         #mis_dates = [pd.to_datetime(start_date).strftime("%Y%m%d") for start_date in missing_ddates]
         #print(state_id," ,",mis_dates)
@@ -331,8 +338,8 @@ class MesonetExtractor:
         #for param in clim_pars:
         #    master_df[clim_pars] = master_df[clim_pars].fillna(neighbor_df[clim_pars])
         #return master_df
-        
-        
+
+
     def change_crs(self, prj_path, bbox):
         '''
         Changes the CRS of a bounding box to EPSG:4269 used by Mesonet.
